@media print{body,html{height:auto!important;overflow:visible!important;overflow:initial!important;-webkit-print-color-adjust:exact;print-color-adjust:exact}.page-break-b{margin-top:1rem;page-break-before:always}.page-break-a{margin-top:1rem;page-break-after:always}.print-large{font-size:2.5rem}}@page{size:auto;margin:20mm}html[data-theme=light]{--border-fsc:#414040;--bg-own-color:#fff;--bg-disabled:#d8d8d8;--nav-bg-active:#0d6efd;--nav-fg-active:#fff;--nav-bg-hoover:#adadad}html[data-theme=dark]{--border-fsc:#bebebe;--bg-own-color:#1e1e1e;--bg-disabled:#333;--nav-bg-active:#0d6efd;--nav-fg-active:#fff;--nav-bg-hoover:#a9a9a9}/*!
 * https://github.com/arqex/react-datetime
 */.rdt{position:relative}.rdtPicker{background:var(--bg-own-color);border:1px solid var(--border-fsc);box-shadow:0 1px 3px #0000001a;display:none;margin-top:1px;min-width:250px;padding:4px;position:absolute;z-index:99999!important}.rdtOpen .rdtPicker{display:block}.rdtStatic .rdtPicker{box-shadow:none;position:static}.rdtPicker .rdtTimeToggle{text-align:center}.rdtPicker table{margin:0;width:100%}.rdtPicker td,.rdtPicker th{height:28px;text-align:center}.rdtPicker td{cursor:pointer}.rdtPicker .rdtTimeToggle:hover,.rdtPicker td.rdtDay:hover,.rdtPicker td.rdtHour:hover,.rdtPicker td.rdtMinute:hover,.rdtPicker td.rdtSecond:hover{background:var(--nav-bg-hoover);cursor:pointer}.rdtPicker td.rdtNew,.rdtPicker td.rdtOld{color:#999}.rdtPicker td.rdtToday{position:relative}.rdtPicker td.rdtToday:before{border-bottom:7px solid #428bca;border-left:7px solid #0000;border-top-color:#0003;bottom:4px;content:"";display:inline-block;position:absolute;right:4px}.rdtPicker td.rdtActive,.rdtPicker td.rdtActive:hover{background-color:var(--nav-bg-active);color:var(--nav-fg-active);text-shadow:0 -1px 0 #00000040}.rdtPicker td.rdtActive.rdtToday:before{border-bottom-color:#fff}.rdtPicker td.rdtDisabled,.rdtPicker td.rdtDisabled:hover{background:none;color:var(--nav-bg-hoover);cursor:not-allowed}.rdtPicker td span.rdtOld{color:#999}.rdtPicker td span.rdtDisabled,.rdtPicker td span.rdtDisabled:hover{background:none;color:var(--nav-bg-hoover);cursor:not-allowed}.rdtPicker th{border-bottom:1px solid var(--border-fsc)}.rdtPicker .dow{border-bottom:none;cursor:default;width:14.2857%}.rdtPicker th.rdtSwitch{width:100px}.rdtPicker th.rdtSwitch:hover{background-color:var(--nav-bg-hoover);width:100px}.rdtPicker th.rdtNext,.rdtPicker th.rdtPrev{font-size:21px;vertical-align:top}.rdtNext span,.rdtPrev span{-webkit-touch-callout:none;display:block;-webkit-user-select:none;user-select:none}.rdtPicker th.rdtDisabled,.rdtPicker th.rdtDisabled:hover{background:none;color:var(--nav-bg-hoover);cursor:not-allowed}.rdtPicker thead tr:first-of-type th{cursor:pointer}.rdtPicker thead tr:first-of-type th:hover{background:var(--nav-bg-hoover)}.rdtPicker tfoot{border-top:1px solid var(--border-fsc)}.rdtPicker button{background:none;border:none;cursor:pointer}.rdtPicker button:hover{background-color:var(--nav-bg-hoover)}.rdtPicker thead button{height:100%;width:100%}td.rdtMonth,td.rdtYear{cursor:pointer;height:50px;width:25%}td.rdtMonth:hover,td.rdtYear:hover{background:var(--nav-bg-hoover)}.rdtCounters{display:inline-block}.rdtCounters>div{float:left}.rdtCounter{height:100px;width:40px}.rdtCounterSeparator{line-height:100px}.rdtCounter .rdtBtn{-webkit-touch-callout:none;cursor:pointer;display:block;height:40%;line-height:40px;-webkit-user-select:none;user-select:none}.rdtCounter .rdtBtn:hover{background:var(--nav-bg-hoover)}.rdtCounter .rdtCount{font-size:1.2em;height:20%}.rdtMilli{padding-left:8px;vertical-align:middle;width:48px}.rdtMilli input{font-size:1.2em;margin-top:37px;width:100%}.rdtTime td{cursor:default}
/*# sourceMappingURL=77.5e8b1e54.chunk.css.map*/