table.Schwarz {
    font-family: "Arial Black", Gadget, sans-serif;
    border: 0.1vh solid #000000;
    background-color: #000000;
    width: 100%;
    text-align: left;
    border-collapse: collapse;
}

table.Schwarz td,
table.Schwarz th {
    border: 0.1vh solid #FFFFFF;
    padding: 0.3vh 0.3vh;
}

table.Schwarz tbody td {
    /* font-size: 13px; */
    color: #FFFFFF;
}

table.Schwarz thead {
    background: #000000;
    border-bottom: 0.3vh solid #FFFFFF;
}

table.Schwarz thead th {
    font-size: 15px;
    font-weight: bold;
    color: #FFFFFF;
    text-align: left;
    border-left: 0.1vh solid #FFFFFF;
}

table.Schwarz thead th:first-child {
    border-left: none;
}